Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1465)

Unified Diff: chrome/browser/installable/installable_logging.h

Issue 2178833002: Add new app banner metrics using InstallableStatusCode. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@banner-integrate-checker-no-refptr
Patch Set: Fix histogram name Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/installable/installable_logging.h
diff --git a/chrome/browser/installable/installable_logging.h b/chrome/browser/installable/installable_logging.h
index 766287abfed8629517c66fdd54904c7c2ccbc437..4ddcd94ee7753e56df945da5f2da29e681d55f58 100644
--- a/chrome/browser/installable/installable_logging.h
+++ b/chrome/browser/installable/installable_logging.h
@@ -12,12 +12,11 @@ class WebContents;
}
// These values are a central reference for installability errors. The
-// InstallableManager will specify an InstallableErrorCode (or
-// NO_ERROR_DETECTED) in its result. Clients may also add their own error codes
-// to this list, and utilise LogErrorToConsole to write a message to the
-// devtools console.
-// TODO(dominickn) add an UMA metric for this enum.
-enum InstallableErrorCode {
+// InstallableManager will specify an InstallableStatusCode (or
+// NO_ERROR_DETECTED) in its result. Clients may also add their own error codes,
+// and utilise LogErrorToConsole to write a message to the devtools console.
+// This enum backs an UMA histogram, so it must be treated as append-only.
+enum InstallableStatusCode {
NO_ERROR_DETECTED,
RENDERER_EXITING,
RENDERER_CANCELLED,
@@ -37,6 +36,14 @@ enum InstallableErrorCode {
PLATFORM_NOT_SUPPORTED_ON_ANDROID,
NO_ID_SPECIFIED,
IDS_DO_NOT_MATCH,
+ ALREADY_INSTALLED,
+ INSUFFICIENT_ENGAGEMENT,
+ PACKAGE_NAME_OR_START_URL_EMPTY,
+ PREVIOUSLY_BLOCKED,
+ PREVIOUSLY_IGNORED,
+ SHOWING_NATIVE_APP_BANNER,
+ SHOWING_WEB_APP_BANNER,
+ FAILED_TO_CREATE_BANNER,
MAX_ERROR_CODE,
};
@@ -44,7 +51,7 @@ enum InstallableErrorCode {
// devtools console attached to |web_contents|. Does nothing if |web_contents|
// is nullptr.
void LogErrorToConsole(content::WebContents* web_contents,
- InstallableErrorCode code,
+ InstallableStatusCode code,
const std::string& param);
#endif // CHROME_BROWSER_INSTALLABLE_INSTALLABLE_LOGGING_H_
« no previous file with comments | « chrome/browser/banners/app_banner_settings_helper_unittest.cc ('k') | chrome/browser/installable/installable_logging.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698